@@ -49,6 +49,8 @@ extern int g_win_button_size;
 extern RD_BOOL g_enable_compose;
 extern RD_BOOL g_use_rdp5;
 extern RD_BOOL g_numlock_sync;
+extern RD_BOOL g_fullscreen;
+extern RD_BOOL g_in_xwin_fullscreen;
 
 static RD_BOOL keymap_loaded;
 static key_translation *keymap[KEYMAP_SIZE];
@@ -507,6 +509,7 @@ reset_winkey(uint32 ev_time)
 RD_BOOL
 handle_special_keys(uint32 keysym, unsigned int state, uint32 ev_time, RD_BOOL pressed)
 {
+	//printf("%i (XK_Execute is: %i)\n", keysym, XK_Execute);
 	switch (keysym)
 	{
 		/* Taking most of these from the old rdesktop port... */
@@ -517,10 +520,26 @@ handle_special_keys(uint32 keysym, unsigned int state, uint32 ev_time, RD_BOOL p
 		//	return True;
 		//	break;
 
+		case XK_Execute: /* Power Key...? */
+			if(pressed && g_fullscreen) {
+				xwin_toggle_fullscreen();
+				return True;
+			}
+			break;
 		case XK_F6: /* HILDON_FULLSCREEN */
 			if(pressed) {
+				//XUnmapWindow(g_display, g_wnd);
+				//g_pressedFullscreen = True;
+				g_in_xwin_fullscreen = True;
+				//printf("g_in_xwin_fullscreen: %s \n", (g_in_xwin_fullscreen)?"true":"false");
 				xwin_toggle_fullscreen();
-				XMapWindow(g_display, g_wnd);
+				//printf("g_in_xwin_fullscreen: %s \n", (g_in_xwin_fullscreen)?"true":"false");
+				g_in_xwin_fullscreen = False;
+				//if(!g_fullscreen) {
+					//XSetIconName(g_display, g_wnd, "pyrdesktop.png");
+					//XIconifyWindow(g_display, g_wnd, DefaultScreen(g_display));
+				//}
+				//XMapWindow(g_display, g_wnd);
 				return True;
 			}
 			break;
